@@ -1,8 +1,11 @@
 from contextlib import contextmanager
+import hashlib
 import importlib
+from pathlib import Path
 import os
 import re
 
+from django.apps import apps
 from django.conf import settings
 from django.db import connections
 from django.test.utils import setup_databases
@@ -18,17 +21,26 @@ def _get_db_backend(connection):
 
 
 def create_test_db(*, verbosity=1):
-    for connection in connections.all():
+    for connection in get_unique_connections():
         connection.creation._create_test_db(
             verbosity=True, autoclobber=True, keepdb=False
         )
 
 
+def get_unique_connections():
+    return [
+        connection
+        for connection in connections.all()
+        if not connection.settings_dict.get("TEST", {}).get("MIRROR")
+    ]
+
+
 def setup_test_db(*, verbosity=1):
     # Based on https://github.com/django/django/blob/d62563cbb194c420f242bfced52b37d6638e67c6/django/test/runner.py#L1051-L1054  # noqa: E501
+    unique_connections = get_unique_connections()
     aliases = []
     database_names = {}
-    for connection in connections.all():
+    for connection in unique_connections:
         aliases.append(connection.alias)
         database_names[connection.alias] = connection.settings_dict["NAME"]
 
@@ -36,7 +48,7 @@ def setup_test_db(*, verbosity=1):
 
     # Django setup_databases change original settings and don't care about it
     # because it run the setup only one time and other parts of testing understand that.
-    for connection in connections.all():
+    for connection in unique_connections:
         database_name = database_names[connection.alias]
         connection.close()
         settings.DATABASES[connection.alias]["NAME"] = database_name
@@ -141,3 +153,18 @@ def load(connection, input_file):
 def dump(connection, output_file):
     backend = _get_db_backend(connection)
     backend.dump(connection, output_file)
+
+
+def hash_files(*files):
+    files = list(files)
+    for app_config in apps.app_configs.values():
+        path = Path(app_config.path)
+        for migration_file in path.glob("migrations/*.py"):
+            files.append(migration_file)
+
+    checksum = hashlib.md5()
+    for _file in sorted(files):
+        with open(_file, "rb") as f:
+            checksum.update(f.read())
+
+    return checksum.hexdigest()
