@@ -65,3 +65,10 @@ def test_migrateci_cached(mocker):
     execute_from_command_line(["manage.py", "migrateci"])
     setup_test_db_mock.assert_not_called()
     _check_db(connections["default"])
+
+
+def test_migrateci_local():
+    execute_from_command_line(["manage.py", "migrateci", "--local"])
+    _check_db(connections["default"])
+    checksum = "b2bed1815363a843fdc8403d36497ddd"
+    assert Path(f"migrateci-default-{checksum}").exists()
